==> qbittorrent_4.1.7.orig.tar.xz: qbittorrent-4.1.7/src/base/utils/bytearray.cpp <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2018  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#include "bytearray.h"

#include <QList>

QList<QByteArray> Utils::ByteArray::splitToViews(const QByteArray &in, const QByteArray &sep, const QString::SplitBehavior behavior)
{
    if (sep.isEmpty())
        return {in};

    QList<QByteArray> ret;

    int head = 0;
    while (head < in.size()) {
        int end = in.indexOf(sep, head);
        if (end < 0)
            end = in.size();

        // omit empty parts
        const QByteArray part = QByteArray::fromRawData((in.constData() + head), (end - head));
        if (!part.isEmpty() || (behavior == QString::KeepEmptyParts))
            ret += part;

        head = end + sep.size();
    }

    return ret;
}

const QByteArray Utils::ByteArray::midView(const QByteArray &in, const int pos, const int len)
{
    if ((pos < 0) || (pos >= in.size()) || (len == 0))
        return {};

    const int validLen = ((len < 0) || (pos + len) >= in.size())
            ? in.size() - pos
            : len;
    return QByteArray::fromRawData(in.constData() + pos, validLen);
}

==> qbittorrent_4.2.5.orig.tar.xz: qbittorrent-4.2.5/src/base/utils/bytearray.cpp <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2018  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#include "bytearray.h"

#include <QByteArray>

QVector<QByteArray> Utils::ByteArray::splitToViews(const QByteArray &in, const QByteArray &sep, const QString::SplitBehavior behavior)
{
    if (sep.isEmpty())
        return {in};

    QVector<QByteArray> ret;
    ret.reserve((behavior == QString::KeepEmptyParts)
                ? (1 + (in.size() / sep.size()))
                : (1 + (in.size() / (sep.size() + 1))));
    int head = 0;
    while (head < in.size()) {
        int end = in.indexOf(sep, head);
        if (end < 0)
            end = in.size();

        // omit empty parts
        const QByteArray part = QByteArray::fromRawData((in.constData() + head), (end - head));
        if (!part.isEmpty() || (behavior == QString::KeepEmptyParts))
            ret += part;

        head = end + sep.size();
    }

    return ret;
}

const QByteArray Utils::ByteArray::midView(const QByteArray &in, const int pos, const int len)
{
    if ((pos < 0) || (pos >= in.size()) || (len == 0))
        return {};

    const int validLen = ((len < 0) || (pos + len) >= in.size())
            ? in.size() - pos
            : len;
    return QByteArray::fromRawData(in.constData() + pos, validLen);
}
